@@ -19,19 +19,24 @@ functions are implemented to support this.
 from ._astropy_init import *
 # ----------------------------------------------------------------------------
 
-#
-# pydl stuff starts here
-#
-from .file_lines import file_lines
-from .pcomp import pcomp
-from .smooth import smooth
-from .uniq import uniq
-from . import goddard
-from . import photoop
-from . import pydlutils
-from . import pydlspec2d
+# For egg_info test builds to pass, put package imports here.
+if not _ASTROPY_SETUP_:
+    from .file_lines import file_lines
+    from .median import median
+    from .pcomp import pcomp
+    from .rebin import rebin
+    from .smooth import smooth
+    from .uniq import uniq
+    # from . import goddard
+    # from . import photoop
+    # from . import pydlutils
+    # from . import pydlspec2d
+
 
 class PydlException(Exception):
+    """Base class for exceptions raised in PyDL functions.
+    """
     pass
 
-__all__ = ['file_lines', 'pcomp', 'smooth', 'uniq', 'PydlException']
+__all__ = ['file_lines', 'median', 'pcomp', 'rebin', 'smooth', 'uniq',
+           'PydlException']
