@@ -1,9 +1,9 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 # -*- coding: utf-8 -*-
-from __future__ import absolute_import, division, print_function, unicode_literals
-#
-def uniq(x,index=None):
-    """Replicates the IDL UNIQ() function.
+
+
+def uniq(x, index=None):
+    """Replicates the IDL ``UNIQ()`` function.
 
     Returns the *subscripts* of the unique elements of an array.  The elements
     must actually be *sorted* before being passed to this function.  This can
@@ -12,21 +12,22 @@ def uniq(x,index=None):
 
     Parameters
     ----------
-    x : array_like
+    x : array-like
         Search this array for unique items.
-    index : array_like, optional
+    index : array-like, optional
         This array provides the array subscripts that sort `x`.
 
     Returns
     -------
-    uniq : array_like
+    array-like
         The subscripts of `x` that are the unique elements of `x`.
 
     Notes
     -----
     Given a sorted array, and assuming that there is a set of
-    adjacent identical items, ``uniq()`` will return the subscript of the *last*
-    unique item.  This charming feature is retained for reproducibility.
+    adjacent identical items, ``uniq()`` will return the subscript of the
+    *last* unique item.  This charming feature is retained for
+    reproducibility.
 
     References
     ----------
@@ -41,15 +42,15 @@ def uniq(x,index=None):
     """
     from numpy import array, roll
     if index is None:
-        indicies = (x != roll(x,-1)).nonzero()[0]
+        indicies = (x != roll(x, -1)).nonzero()[0]
         if indicies.size > 0:
             return indicies
         else:
-            return array([x.size - 1,])
+            return array([x.size - 1, ])
     else:
         q = x[index]
-        indicies = (q != roll(q,-1)).nonzero()[0]
+        indicies = (q != roll(q, -1)).nonzero()[0]
         if indicies.size > 0:
             return index[indicies]
         else:
-            return array([q.size - 1,],dtype=index.dtype)
+            return array([q.size - 1, ], dtype=index.dtype)
